@@ -23,6 +23,7 @@
 #include <lttoolbox/xml_parse_util.h>
 
 #include <cctype>
+#include <cerrno>
 #include <iostream>
 #include <stack>
 #include <apertium/string_utils.h>
@@ -57,6 +58,9 @@ Interchunk::Interchunk()
   doc = NULL;
   root_element = NULL;
   lastrule = NULL;
+  inword = false;
+  null_flush = false;
+  internal_null_flush = false;
 }
 
 Interchunk::~Interchunk()
@@ -239,7 +243,15 @@ Interchunk::evalString(xmlNode *element)
       case ti_clip_tl:
         if(checkIndex(element, ti.getPos(), lword))
         {
-          return word[ti.getPos()]->chunkPart(attr_items[ti.getContent()]);
+          if(ti.getContent() == "content") // jacob's new 'part'
+          { 
+            string wf = word[ti.getPos()]->chunkPart(attr_items[ti.getContent()]);
+            return wf.substr(1, wf.length()-2); // trim away the { and }  
+          }
+          else
+          {
+            return word[ti.getPos()]->chunkPart(attr_items[ti.getContent()]);
+          }
         }
         break;
         
@@ -360,6 +372,19 @@ Interchunk::evalString(xmlNode *element)
       
     evalStringCache[element] = TransferInstr(ti_case_of_tl, (const char *) part, pos);
   }
+  else if(!xmlStrcmp(element->name, (const xmlChar *) "concat"))
+  { 
+    string value = "";
+    for(xmlNode *i = element->children; i != NULL; i = i->next)
+    {
+      if(i->type == XML_ELEMENT_NODE)
+      {
+        value.append(evalString(i));
+      }
+    }
+    return value;
+  }
+
   else
   {
     cerr << "Error: unexpected rvalue expression '" << element->name << endl;
@@ -633,11 +658,11 @@ Interchunk::processCallMacro(xmlNode *localroot)
 
   if(myword)
   {
-    delete myword;
+    delete[] myword;
   }
   if(myblank)
   {
-    delete myblank;
+    delete[] myblank;
   }
 }
 
@@ -1258,7 +1283,7 @@ Interchunk::readToken(FILE *in)
   while(true)
   {
     int val = fgetwc_unlocked(in);
-    if(feof(in))
+    if(feof(in) || (internal_null_flush && val == 0))
     {
       return input_buffer.add(TransferToken(content, tt_eof));
     }
@@ -1289,7 +1314,7 @@ Interchunk::readToken(FILE *in)
 	}
       }
     }
-    else if(val == L'{')
+    else if(inword && val == L'{')
     {
       content += L'{';
       while(true)
@@ -1302,8 +1327,14 @@ Interchunk::readToken(FILE *in)
 	}
 	else if(val2 == L'}')
 	{
+	  wint_t val3 = wchar_t(fgetwc_unlocked(in));
+	  ungetwc(val3, in);
+	  
 	  content += L'}';
-	  break;
+	  if(val3 == L'$')
+	  {
+	    break;  
+	  }
 	}
 	else
 	{
@@ -1311,12 +1342,14 @@ Interchunk::readToken(FILE *in)
 	}
       }
     }
-    else if(val == L'$')
+    else if(inword && val == L'$')
     {
+      inword = false;
       return input_buffer.add(TransferToken(content, tt_word));
     }
     else if(val == L'^')
     {
+      inword = true;
       return input_buffer.add(TransferToken(content, tt_blank));
     }
     else
@@ -1326,9 +1359,47 @@ Interchunk::readToken(FILE *in)
   }
 }
 
+bool
+Interchunk::getNullFlush(void)
+{
+  return null_flush;
+}
+
+void
+Interchunk::setNullFlush(bool null_flush)
+{
+  this->null_flush = null_flush;
+}
+
+void
+Interchunk::interchunk_wrapper_null_flush(FILE *in, FILE *out)
+{
+  null_flush = false;
+  internal_null_flush = true;
+  
+  while(!feof(in))
+  {
+    interchunk(in, out);
+    fputwc_unlocked(L'\0', out);
+    int code = fflush(out);
+    if(code != 0)
+    {
+      wcerr << L"Could not flush output " << errno << endl;
+    }
+  }
+  internal_null_flush = false;
+  null_flush = true;
+}    
+
+
 void
 Interchunk::interchunk(FILE *in, FILE *out)
 {
+  if(getNullFlush())
+  {
+    interchunk_wrapper_null_flush(in, out);
+  }
+  
   int last = 0;
 
   output = out;
@@ -1445,7 +1516,7 @@ Interchunk::applyRule()
     {
       delete word[i];
     }
-    delete word;
+    delete[] word;
   }
   if(blank)
   {
@@ -1453,7 +1524,7 @@ Interchunk::applyRule()
     {
       delete blank[i];
     }
-    delete blank;
+    delete[] blank;
   }
   word = NULL;
   blank = NULL;
