@@ -70,7 +70,10 @@ private:
   unsigned int nwords;
   
   map<xmlNode *, TransferInstr> evalStringCache;
-
+  bool inword;
+  bool null_flush;
+  bool internal_null_flush;
+  
   void copy(Interchunk const &o);
   void destroy();
   void readData(FILE *input);
@@ -113,7 +116,9 @@ private:
   void applyWord(wstring const &word_str);
   void applyRule();
   TransferToken & readToken(FILE *in);
-  bool checkIndex(xmlNode *element, int index, int limit);  
+  bool checkIndex(xmlNode *element, int index, int limit); 
+  void interchunk_wrapper_null_flush(FILE *in, FILE *out);
+
 public:
   Interchunk();
   ~Interchunk();
@@ -122,6 +127,9 @@ public:
   
   void read(string const &transferfile, string const &datafile);
   void interchunk(FILE *in, FILE *out);
+  bool getNullFlush(void);
+  void setNullFlush(bool null_flush);
+
 };
 
 #endif
