@@ -23,6 +23,7 @@
 #include <lttoolbox/xml_parse_util.h>
 
 #include <cctype>
+#include <cerrno>
 #include <iostream>
 #include <stack>
 #include <apertium/string_utils.h>
@@ -57,6 +58,9 @@ Postchunk::Postchunk()
   doc = NULL;
   root_element = NULL;
   lastrule = NULL;
+  inword = false;
+  null_flush = false;
+  internal_null_flush = false;
 }
 
 Postchunk::~Postchunk()
@@ -242,6 +246,9 @@ Postchunk::evalString(xmlNode *element)
           return word[ti.getPos()]->chunkPart(attr_items[ti.getContent()]);
         }
         break;
+        
+      case ti_lu_count:
+        return StringUtils::itoa_string(tmpword.size());
 
       case ti_var:
         return variables[ti.getContent()];
@@ -341,6 +348,10 @@ Postchunk::evalString(xmlNode *element)
   {
     evalStringCache[element] = TransferInstr(ti_var, (const char *) element->properties->children->content, 0);
   }
+  else if(!xmlStrcmp(element->name, (const xmlChar *) "lu-count"))
+  {
+    evalStringCache[element] = TransferInstr(ti_lu_count, "", 0);
+  }
   else if(!xmlStrcmp(element->name, (const xmlChar *) "case-of"))
   {
     int pos = 0;
@@ -626,9 +637,9 @@ Postchunk::processCallMacro(xmlNode *localroot)
     myword = new InterchunkWord *[npar+1];  
   }
   string **myblank = NULL;
-  if(npar > 1)
+  if(npar > 0)
   {
-    myblank = new string *[npar - 1];
+    myblank = new string *[npar];
   }
 
   myword[0] = word[0];
@@ -641,10 +652,11 @@ Postchunk::processCallMacro(xmlNode *localroot)
     {
       int pos = atoi((const char *) i->properties->children->content);
       myword[idx] = word[pos];
-      if(idx > 1)
+      if(blank)
       {
         myblank[idx-1] = blank[lastpos];
       }
+      
       idx++;
       lastpos = pos;
     }
@@ -668,11 +680,11 @@ Postchunk::processCallMacro(xmlNode *localroot)
 
   if(myword)
   {
-    delete myword;
+    delete[] myword;
   }
   if(myblank)
   {
-    delete myblank;
+    delete[] myblank;
   }
 }
 
@@ -1329,7 +1341,7 @@ Postchunk::readToken(FILE *in)
   while(true)
   {
     int val = fgetwc_unlocked(in);
-    if(feof(in))
+    if(feof(in) || (internal_null_flush && val == 0))
     {
       return input_buffer.add(TransferToken(content, tt_eof));
     }
@@ -1360,7 +1372,7 @@ Postchunk::readToken(FILE *in)
 	}
       }
     }
-    else if(val == L'{')
+    else if(inword && val == L'{')
     {
       content += L'{';
       while(true)
@@ -1373,8 +1385,14 @@ Postchunk::readToken(FILE *in)
 	}
 	else if(val2 == L'}')
 	{
+	  int val3 = wchar_t(fgetwc_unlocked(in));
+	  ungetwc(val3, in);
+	  
 	  content += L'}';
-	  break;
+	  if(val3 == L'$')
+	  {
+	    break;  
+	  }
 	}
 	else
 	{
@@ -1382,12 +1400,14 @@ Postchunk::readToken(FILE *in)
 	}
       }
     }
-    else if(val == L'$')
+    else if(inword && val == L'$')
     {
+      inword = false;
       return input_buffer.add(TransferToken(content, tt_word));
     }
     else if(val == L'^')
     {
+      inword = true;
       return input_buffer.add(TransferToken(content, tt_blank));
     }
     else
@@ -1397,9 +1417,47 @@ Postchunk::readToken(FILE *in)
   }
 }
 
+bool
+Postchunk::getNullFlush(void)
+{
+  return null_flush;
+}
+
+void
+Postchunk::setNullFlush(bool null_flush)
+{
+  this->null_flush = null_flush;
+}
+
+void
+Postchunk::postchunk_wrapper_null_flush(FILE *in, FILE *out)
+{
+  null_flush = false;
+  internal_null_flush = true;
+  
+  while(!feof(in))
+  {
+    postchunk(in, out);
+    fputwc_unlocked(L'\0', out);
+    int code = fflush(out);
+    if(code != 0)
+    {
+      wcerr << L"Could not flush output " << errno << endl;
+    }
+  }
+  
+  internal_null_flush = false;
+  null_flush = true;
+}    
+
 void
 Postchunk::postchunk(FILE *in, FILE *out)
 {
+  if(getNullFlush())
+  {
+    postchunk_wrapper_null_flush(in, out);
+  }
+  
   int last = 0;
 
   output = out;
