@@ -70,6 +70,10 @@ private:
   
   map<xmlNode *, TransferInstr> evalStringCache;
 
+  bool inword;
+  bool null_flush;
+  bool internal_null_flush;
+
   void copy(Postchunk const &o);
   void destroy();
   void readData(FILE *input);
@@ -121,6 +125,8 @@ private:
   static wstring pseudolemma(wstring const &chunk);
   static wstring wordzero(wstring const &chunk);
   bool checkIndex(xmlNode *element, int index, int limit);  
+  void postchunk_wrapper_null_flush(FILE *in, FILE *out);
+
 public:
   Postchunk();
   ~Postchunk();
@@ -129,6 +135,9 @@ public:
   
   void read(string const &transferfile, string const &datafile);
   void postchunk(FILE *in, FILE *out);
+  bool getNullFlush(void);
+  void setNullFlush(bool null_flush);
+
 };
 
 #endif
