@@ -170,6 +170,18 @@ TaggerData::setPreferRules(vector<wstring> const &pr)
   prefer_rules = pr;
 }
 
+vector<wstring> &
+TaggerData::getDiscardRules()
+{
+  return discard;
+}
+
+void
+TaggerData::setDiscardRules(vector<wstring> const &v)
+{
+  discard = v;
+}
+
 ConstantManager &
 TaggerData::getConstants()
 {
@@ -182,7 +194,6 @@ TaggerData::setConstants(ConstantManager const &c)
   constants = c;
 }
 
-
 Collection &
 TaggerData::getOutput()
 {
@@ -378,7 +389,21 @@ TaggerData::read(FILE *in)
   }
 
   // read pattern list
-  plist.read(in); 
+  plist.read(in);
+    
+  // read discards on ambiguity
+  discard.clear();
+
+  int limit = Compression::multibyte_read(in);  
+  if(feof(in))
+  {
+    return;
+  }
+  
+  for(int i = 0; i < limit; i++)
+  {
+    discard.push_back(Compression::wstring_read(in));
+  }
 }
 
 void
@@ -485,4 +510,21 @@ TaggerData::write(FILE *out)
   
   // write pattern list
   plist.write(out);
+  
+  // write discard list
+  
+  if(discard.size() != 0)
+  {
+    Compression::multibyte_write(discard.size(), out);
+    for(unsigned int i = 0, limit = discard.size(); i != limit; i++)
+    {
+      Compression::wstring_write(discard[i], out);
+    }
+  }  
+}
+
+void
+TaggerData::addDiscard(wstring const &tags)
+{
+  discard.push_back(tags);
 }
