@@ -49,6 +49,8 @@ private:
   double **b;
   PatternList plist;
 
+  vector<wstring> discard;
+  
   void copy(TaggerData const &o);
   void destroy();
 public:
@@ -74,6 +76,9 @@ public:
 
   vector<wstring> & getPreferRules();
   void setPreferRules(vector<wstring> const &pr);
+  
+  vector<wstring> & getDiscardRules();
+  void setDiscardRules(vector<wstring> const &dr);
 
   ConstantManager & getConstants();
   void setConstants(ConstantManager const &c);
@@ -89,7 +94,7 @@ public:
   virtual int getM();
   
   void setPatternList(PatternList const &pl);
-
+  void addDiscard(wstring const &tags);
   PatternList & getPatternList();
   
   void read(FILE *in);
