@@ -26,6 +26,7 @@
 #include <cctype>
 #include <iostream>
 #include <stack>
+#include <cerrno>
 
 using namespace Apertium;
 using namespace std;
@@ -59,6 +60,8 @@ Transfer::Transfer()
   defaultAttrs = lu;
   useBilingual = true;
   isExtended = false;
+  null_flush = false;
+  internal_null_flush = false;
 }
 
 Transfer::~Transfer()
@@ -1035,11 +1038,11 @@ Transfer::processCallMacro(xmlNode *localroot)
   
   if(myword)
   {
-    delete myword;
+    delete[] myword;
   }
   if(myblank)
   {
-    delete myblank;
+    delete[] myblank;
   }
 }
 
@@ -1663,7 +1666,7 @@ Transfer::readToken(FILE *in)
   while(true)
   {
     int val = fgetwc_unlocked(in);
-    if(feof(in))
+    if(feof(in) || (val == 0 && internal_null_flush))
     {
       return input_buffer.add(TransferToken(content, tt_eof));
     }
@@ -1709,9 +1712,47 @@ Transfer::readToken(FILE *in)
   }
 }
 
+bool
+Transfer::getNullFlush(void)
+{
+  return null_flush;
+}
+
+void
+Transfer::setNullFlush(bool null_flush)
+{
+  this->null_flush = null_flush;
+}
+
+void
+Transfer::transfer_wrapper_null_flush(FILE *in, FILE *out)
+{
+  null_flush = false;
+  internal_null_flush = true;
+  
+  while(!feof(in))
+  {
+    transfer(in, out);
+    fputwc_unlocked(L'\0', out);
+    int code = fflush(out);
+    if(code != 0)
+    {
+      wcerr << L"Could not flush output " << errno << endl;
+    }
+  }
+
+  internal_null_flush = false;
+  null_flush = true;
+}    
+
 void
 Transfer::transfer(FILE *in, FILE *out)
 {
+  if(getNullFlush())
+  {
+    transfer_wrapper_null_flush(in, out);
+  }
+  
   int last = 0;
 
   output = out;
@@ -1883,7 +1924,7 @@ Transfer::applyRule()
     {
       delete word[i];
     }
-    delete word;
+    delete[] word;
   }
   if(blank)
   {
@@ -1891,7 +1932,7 @@ Transfer::applyRule()
     {
       delete blank[i];
     }
-    delete blank;
+    delete[] blank;
   }
   word = NULL;
   blank = NULL;
@@ -1957,4 +1998,4 @@ void
 Transfer::setCaseSensitiveness(bool value)
 {
   fstp.setCaseSensitiveMode(value);
-}
\ No newline at end of file
+}
