@@ -141,6 +141,46 @@ TSXReader::newConstant(wstring const &constant)
   array_tags->push_back(constant);
 }
 
+void
+TSXReader::procDiscardOnAmbiguity()
+{
+  while(type != XML_READER_TYPE_END_ELEMENT || name != L"discard-on-ambiguity")
+  {
+    step();
+
+    if(name == L"discard")
+    {
+      if(type != XML_READER_TYPE_END_ELEMENT)
+      {
+        tdata.addDiscard(L"<" + StringUtils::substitute(attrib(L"tags"), L".", L"><") + L">");
+      }
+    }
+    else if(name == L"#text")
+    {
+      // do nothing
+    }
+    else if(name == L"#comment")
+    {
+      // do nothing
+    }
+    else if(name == L"discard-on-ambiguity")
+    {
+      if(type == XML_READER_TYPE_END_ELEMENT)
+      {
+	break;
+      }
+      else
+      {
+	parseError(L"Unexpected 'discard-on-ambiguity' open tag");
+      }
+    }
+    else
+    {
+      parseError(L"unexpected '<" + name + L">' tag");
+    }
+  }
+}
+
 void
 TSXReader::procDefLabel()
 {
@@ -515,6 +555,18 @@ TSXReader::read(string const &filename)
   if(name == L"preferences")
   {
     procPreferences();
+    step();
+    while(name == L"#text" || name == L"#comment")
+    {
+      step();
+    }
+  }
+  if(name == L"discard-on-ambiguity")
+  {
+    if(type != XML_READER_TYPE_END_ELEMENT)
+    {
+      procDiscardOnAmbiguity();
+    }
   }
 
   xmlFreeTextReader(reader);
